@@ -145,24 +145,34 @@ class TestStylesheet:
 
     def test_custom_number_formats(self, Stylesheet, datadir):
         datadir.chdir()
-        import codecs
-        with codecs.open("styles_number_formats.xml", encoding="utf-8") as src:
-            xml = src.read().encode("utf8") # Python 2.6, Windows
-
+        with open("styles_number_formats.xml", "rb") as src:
+            xml = src.read()
         node = fromstring(xml)
         stylesheet = Stylesheet.from_tree(node)
 
-        assert stylesheet.number_formats == [
-            '_ * #,##0.00_ ;_ * \-#,##0.00_ ;_ * "-"??_ ;_ @_ ',
+        assert set(stylesheet.number_formats) == set([
+            r'_ * #,##0.00_ ;_ * \-#,##0.00_ ;_ * "-"??_ ;_ @_ ',
             "#,##0.00_ ",
             "yyyy/m/d;@",
             "0.00000_ "
-        ]
+        ])
+
+
+    def test_remove_duplicate_number_formats(self, Stylesheet, datadir):
+        datadir.chdir()
+
+        with open("builtins_as_custom_number_formats.xml", "rb") as src:
+            xml = src.read()
+            node = fromstring(xml)
+
+        stylesheet = Stylesheet.from_tree(node)
+
+        assert stylesheet.number_formats == ['dd\\/mm']
 
 
     def test_assign_number_formats(self, Stylesheet):
 
-        node = fromstring("""
+        node = fromstring(r"""
         <styleSheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main">
         <numFmts count="1">
           <numFmt numFmtId="43" formatCode='_ * #,##0.00_ ;_ * \-#,##0.00_ ;_ * "-"??_ ;_ @_ ' />
@@ -182,8 +192,6 @@ class TestStylesheet:
 
 
     def test_named_styles(self, datadir, Stylesheet):
-        from openpyxl.styles.named_styles import NamedStyle
-        from openpyxl.styles.fonts import DEFAULT_FONT
         from openpyxl.styles.fills import DEFAULT_EMPTY_FILL
         from openpyxl.styles.borders import Border
 
