@@ -1,11 +1,8 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import pytest
 
-from openpyxl.xml.functions import fromstring, tostring
-from openpyxl.tests.helper import compare_xml
-
 
 class DummyWorkbook:
 
@@ -26,6 +23,6 @@ class TestReadOnlyWorksheet:
         datadir.chdir()
 
         ws = ReadOnlyWorksheet(DummyWorkbook(), "Sheet", "", "sheet_inline_strings.xml", [])
-        cells = tuple(ws.get_squared_range(1, 1, 1, 1))
+        cells = tuple(ws.iter_rows(min_row=1, min_col=1, max_row=1, max_col=1))
         assert len(cells) == 1
         assert cells[0][0].value == "col1"
